summaryrefslogtreecommitdiffstats
path: root/tdehtml/ecma/kjs_proxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdehtml/ecma/kjs_proxy.h')
-rw-r--r--tdehtml/ecma/kjs_proxy.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdehtml/ecma/kjs_proxy.h b/tdehtml/ecma/kjs_proxy.h
index 5ea2d5bf6..bac9e9579 100644
--- a/tdehtml/ecma/kjs_proxy.h
+++ b/tdehtml/ecma/kjs_proxy.h
@@ -26,7 +26,7 @@
#include <tqstring.h>
#include <sys/time.h>
-class KHTMLPart;
+class TDEHTMLPart;
namespace DOM {
class Node;
@@ -72,8 +72,8 @@ public:
tdehtml::ChildFrame *m_frame;
int m_handlerLineno;
- // Helper method, to access the private KHTMLPart::jScript()
- static KJSProxy *proxy( KHTMLPart *part );
+ // Helper method, to access the private TDEHTMLPart::jScript()
+ static KJSProxy *proxy( TDEHTMLPart *part );
};
class KJSCPUGuard {